@@ -3,13 +3,13 @@ OC.L10N.register(
     {
     "Added to the list of trusted servers" : "Dodano na spisek varnih strežnikov",
     "Server is already in the list of trusted servers." : "Strežnik je že na seznamu potrjenih strežnikov.",
-    "No server to federate found" : "Ne najdem strežnika za federiranje",
+    "No server to federate with found" : "Ne najdem strežnika za federiranje",
     "Could not add server" : "Ni mogoče dodati strežnika.",
-    "Federation" : "Zvezni oblaki",
     "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federiranje omogoča povezovanje z drugimi varnimi strežniki in izmenjavo spiska uporabnikov. Primer je samodejno dopolnjevanje zunanjih uporabnikov pri federacijski souporabi.",
+    "Trusted servers" : "Zanesljivi strežniki",
     "Add server automatically once a federated share was created successfully" : "Strežnik dodaj samodejno, ko je povezava zveznega oblaka uspešno ustvarjena",
-    "Trusted Servers" : "Varni strežniki",
-    "+ Add ownCloud server" : "+ Dodaj strežnik ownCloud",
-    "ownCloud Server" : "Strežnik ownCloud"
+    "+ Add trusted server" : "+ Dodaj zanesljiv strežnik",
+    "Trusted server" : "Zanesljiv strežnik",
+    "Add" : "Dodaj"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
