@@ -1,8 +1,8 @@
 OC.L10N.register(
     "files_sharing",
     {
-    "Shared with you" : "Delat med dig",
     "Shared with others" : "Delat med andra",
+    "Shared with you" : "Delat med dig",
     "Shared by link" : "Delat som länk",
     "Nothing shared with you yet" : "Inget delat med dig ännu",
     "Files and folders others share with you will show up here" : "Filer och mappar som andra delar med dig kommer visas här",
@@ -10,6 +10,7 @@ OC.L10N.register(
     "Files and folders you share will show up here" : "Filer och mappar som du delar kommer visas här",
     "No shared links" : "Inga delade länkar",
     "Files and folders you share by link will show up here" : "Filer och mappar som du delar som länkar kommer visas här",
+    "Download" : "Ladda ned",
     "You can upload into this folder" : "Du kan ladda upp i denna mapp",
     "No compatible server found at {remote}" : "Ingen kompatibel server hittad på {remote}",
     "Invalid server URL" : "Ogiltig server URL",
@@ -60,7 +61,6 @@ OC.L10N.register(
     "{actor} shared {file} with {user}" : "{actor} delade {file} med {user}",
     "{actor} removed {user} from {file}" : "{actor} tog bort {user} från {file}",
     "{actor} shared {file} with you" : "{actor} delade {file} med dig",
-    "{actor} removed you from {file}" : "{actor} tog bort dig från {file}",
     "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "En fil eller mapp som delats via mejl eller offentlig länk har blivit <strong>nedladdad</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "En fil eller mapp delades från <strong>en annan server</strong>",
     "A file or folder has been <strong>shared</strong>" : "En fil eller mapp har <strong>delats</strong>",
@@ -87,10 +87,10 @@ OC.L10N.register(
     "Wrong or no update parameter given" : "Fel eller ingen uppdateringsparameter angiven",
     "Can't change permissions for public share links" : "Det går inte att ändra behörigheterna för offentliga länkar",
     "Cannot increase permissions" : "Kan inte utöka behörigheter",
+    "shared by %s" : "delad av %s",
+    "Direct link" : "Direktlänk",
+    "Add to your Nextcloud" : "Lägg till i molnet",
     "Share API is disabled" : "Delning av API är inaktiverad",
-    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
-    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
-    "Password" : "Lösenord",
     "No entries found in this folder" : "Inga filer hittades i denna mapp",
     "Name" : "Namn",
     "Share time" : "Delningstid",
@@ -101,15 +101,14 @@ OC.L10N.register(
     "the link expired" : "giltighet för länken har gått ut",
     "sharing is disabled" : "delning är inaktiverat",
     "For more info, please ask the person who sent this link." : "För mer information, kontakta den person som skickade den här länken.",
-    "shared by %s" : "delad av %s",
-    "Download" : "Ladda ned",
-    "Direct link" : "Direktlänk",
-    "Add to your Nextcloud" : "Lägg till i molnet",
     "Download %s" : "Ladda ned %s",
     "Upload files to %s" : "Ladda upp filer till %s",
     "Select or drop files" : "Välj eller dra filer hit",
     "Uploading files…" : "Laddar upp filer...",
     "Uploaded files:" : "Uppladdade filer:",
-    "%s is publicly shared" : "%s är offentligt delad"
+    "{actor} removed you from {file}" : "{actor} tog bort dig från {file}",
+    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
+    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
+    "Password" : "Lösenord"
 },
 "nplurals=2; plural=(n != 1);");
