@@ -2,7 +2,9 @@
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
+ * @author Bjoern Schiessle <bjoern@schiessle.org>
  * @author Björn Schießle <bjoern@schiessle.org>
+ * @author Daniel Hansson <daniel@techandme.se>
  * @author Joas Schilling <coding@schilljs.com>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
  * @author Lukas Reschke <lukas@statuscode.ch>
@@ -30,10 +32,13 @@
 namespace OCA\Files_Sharing\External;
 
 use OC\Files\Filesystem;
-use OCA\FederatedFileSharing\DiscoveryManager;
+use OCA\Files_Sharing\Helper;
 use OCP\Files;
+use OCP\Files\Storage\IStorageFactory;
 use OCP\Http\Client\IClientService;
+use OCP\IDBConnection;
 use OCP\Notification\IManager;
+use OCP\OCS\IDiscoveryService;
 
 class Manager {
 	const STORAGE = '\OCA\Files_Sharing\External\Storage';
@@ -44,7 +49,7 @@ class Manager {
 	private $uid;
 
 	/**
-	 * @var \OCP\IDBConnection
+	 * @var IDBConnection
 	 */
 	private $connection;
 
@@ -54,7 +59,7 @@ class Manager {
 	private $mountManager;
 
 	/**
-	 * @var \OCP\Files\Storage\IStorageFactory
+	 * @var IStorageFactory
 	 */
 	private $storageLoader;
 
@@ -67,24 +72,27 @@ class Manager {
 	 * @var IManager
 	 */
 	private $notificationManager;
-	/** @var DiscoveryManager */
-	private $discoveryManager;
 
 	/**
-	 * @param \OCP\IDBConnection $connection
+	 * @var IDiscoveryService
+	 */
+	private $discoveryService;
+
+	/**
+	 * @param IDBConnection $connection
 	 * @param \OC\Files\Mount\Manager $mountManager
-	 * @param \OCP\Files\Storage\IStorageFactory $storageLoader
+	 * @param IStorageFactory $storageLoader
 	 * @param IClientService $clientService
 	 * @param IManager $notificationManager
-	 * @param DiscoveryManager $discoveryManager
+	 * @param IDiscoveryService $discoveryService
 	 * @param string $uid
 	 */
-	public function __construct(\OCP\IDBConnection $connection,
+	public function __construct(IDBConnection $connection,
 								\OC\Files\Mount\Manager $mountManager,
-								\OCP\Files\Storage\IStorageFactory $storageLoader,
+								IStorageFactory $storageLoader,
 								IClientService $clientService,
 								IManager $notificationManager,
-								DiscoveryManager $discoveryManager,
+								IDiscoveryService $discoveryService,
 								$uid) {
 		$this->connection = $connection;
 		$this->mountManager = $mountManager;
@@ -92,7 +100,7 @@ class Manager {
 		$this->clientService = $clientService;
 		$this->uid = $uid;
 		$this->notificationManager = $notificationManager;
-		$this->discoveryManager = $discoveryManager;
+		$this->discoveryService = $discoveryService;
 	}
 
 	/**
@@ -191,11 +199,13 @@ class Manager {
 	public function acceptShare($id) {
 
 		$share = $this->getShare($id);
+		$result = false;
 
 		if ($share) {
 			\OC_Util::setupFS($this->uid);
-			$mountPoint = Files::buildNotExistingFileName('/', $share['name']);
-			$mountPoint = Filesystem::normalizePath('/' . $mountPoint);
+			$shareFolder = Helper::getShareFolder();
+			$mountPoint = Files::buildNotExistingFileName($shareFolder, $share['name']);
+			$mountPoint = Filesystem::normalizePath($mountPoint);
 			$hash = md5($mountPoint);
 
 			$acceptShare = $this->connection->prepare('
@@ -204,16 +214,18 @@ class Manager {
 					`mountpoint` = ?,
 					`mountpoint_hash` = ?
 				WHERE `id` = ? AND `user` = ?');
-			$acceptShare->execute(array(1, $mountPoint, $hash, $id, $this->uid));
-			$this->sendFeedbackToRemote($share['remote'], $share['share_token'], $share['remote_id'], 'accept');
-
-			\OC_Hook::emit('OCP\Share', 'federated_share_added', ['server' => $share['remote']]);
-
-			$this->processNotification($id);
-			return true;
+			$updated = $acceptShare->execute(array(1, $mountPoint, $hash, $id, $this->uid));
+			if ($updated === true) {
+				$this->sendFeedbackToRemote($share['remote'], $share['share_token'], $share['remote_id'], 'accept');
+				\OC_Hook::emit('OCP\Share', 'federated_share_added', ['server' => $share['remote']]);
+				$result = true;
+			}
 		}
 
-		return false;
+		// Make sure the user has no notification for something that does not exist anymore.
+		$this->processNotification($id);
+
+		return $result;
 	}
 
 	/**
@@ -261,7 +273,10 @@ class Manager {
 	 */
 	private function sendFeedbackToRemote($remote, $token, $remoteId, $feedback) {
 
-		$url = rtrim($remote, '/') . $this->discoveryManager->getShareEndpoint($remote) . '/' . $remoteId . '/' . $feedback . '?format=' . \OCP\Share::RESPONSE_FORMAT;
+		$federationEndpoints = $this->discoveryService->discover($remote, 'FEDERATED_SHARING');
+		$endpoint = isset($federationEndpoints['share']) ? $federationEndpoints['share'] : '/ocs/v2.php/cloud/shares';
+
+		$url = rtrim($remote, '/') . $endpoint . '/' . $remoteId . '/' . $feedback . '?format=' . \OCP\Share::RESPONSE_FORMAT;
 		$fields = array('token' => $token);
 
 		$client = $this->clientService->newClient();
@@ -356,8 +371,13 @@ class Manager {
 		$result = $getShare->execute(array($hash, $this->uid));
 
 		if ($result) {
-			$share = $getShare->fetch();
-			$this->sendFeedbackToRemote($share['remote'], $share['share_token'], $share['remote_id'], 'decline');
+			try {
+				$share = $getShare->fetch();
+				$this->sendFeedbackToRemote($share['remote'], $share['share_token'], $share['remote_id'], 'decline');
+			} catch (\Exception $e) {
+				// if we fail to notify the remote (probably cause the remote is down)
+				// we still want the share to be gone to prevent undeletable remotes
+			}
 		}
 		$getShare->closeCursor();
 
@@ -377,7 +397,7 @@ class Manager {
 
 	/**
 	 * remove re-shares from share table and mapping in the federated_reshares table
-	 * 
+	 *
 	 * @param $mountPointId
 	 */
 	protected function removeReShares($mountPointId) {
