@@ -2,9 +2,19 @@ OC.L10N.register(
     "updatenotification",
     {
     "{version} is available. Get more information on how to update." : "La version {version} est disponible. Cliquez ici pour plus d'informations sur comment mettre à jour.",
+    "Update notifications" : "Notifications de mises à jour",
+    "Channel updated" : "Canal de mise à jour modifié",
+    "The update server could not be reached since %d days to check for new updates." : "Le serveur de mise à jour n'a pas pu être atteint depuis %d jours pour vérifier les nouvelles mises à jour.",
+    "Please check the Nextcloud and server log files for errors." : "Veuillez vérifier les fichiers de log de Nextcloud et du serveur pour les erreurs.",
+    "Update to %1$s is available." : "Une mise à jour vers %1$s est disponible",
+    "Update for %1$s to version %2$s is available." : "Une mise à jour de %1$s vers la version %2$s est disponible.",
+    "Update for {app} to version %s is available." : "Une mise à jour de {app} vers la version %s est disponible.",
+    "Update notification" : "Notification mise à jour",
+    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Affiche les notifications de mise à jour pour Nextcloud et fournit l'authentification unique SSO pour le programme de mise à jour.",
     "Apps with available updates" : "Applications avec des mises à jour disponibles",
     "Open updater" : "Ouvrir le système de mise à jour",
-    "Your version is up to date." : "Votre version est à jour.",
+    "What's new?" : "Quoi de neuf ?",
+    "The update check is not yet finished. Please refresh the page." : "La vérification de la mise-à-jour n'est pas encore terminée. Veuillez rafraîchir la page.",
     "A non-default update server is in use to be checked for updates:" : "Un serveur spécifique est actuellement configuré pour la vérification des mises-à-jour :",
     "Update channel:" : "Canal de mise à jour :",
     "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Vous pouvez à tout moment mettre à jour votre instance Nextcloud vers une version plus récente ou un canal expérimental. Vous ne pourrez cependant jamais revenir à une version antérieure en sélectionnant un canal plus stable.",
@@ -20,22 +30,15 @@ OC.L10N.register(
     "<strong>All</strong> apps have an update for this version available" : "<strong>Toutes</strong> les applications ont une mise à jour disponible pour cette version",
     "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong>  application n'a pas de mise à jour disponible pour cette version","<strong>%n</strong> applications n'ont pas de mise à jour disponible pour cette version"],
     "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>production</strong> fournira toujours le correctif le plus récent, mais ne mettra pas immédiatement à jour vers la version majeure suivante. Cette mise à jour se produit généralement avec la deuxième version mineure (x.0.2).",
-    "<strong>stable</strong> is the most recent stable version. It is suited for production use and will always update to the latest major version." : "<strong>stable</strong> est la version stable la plus récente. Il est adapté à une utilisation en production et sera toujours mis à jour vers la dernière version majeure.",
+    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>stable</strong> est la version stable la plus récente. Elle est adapté pour une utilisation régulière et sera toujours mise à jour vers la dernière version majeure.",
     "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>beta</strong> est une version préliminaire utilisée seulement pour tester les nouvelles fonctionnalités, n'est pas adaptée dans un environnement de production.",
+    "View changelog" : "Voir le journal des modifications",
     "Could not start updater, please try the manual update" : "Impossible de démarrer le système de mise à jour, veuillez essayer de mettre à jour manuellement",
-    "Update notifications" : "Notifications de mises à jour",
-    "Channel updated" : "Canal de mise à jour modifié",
-    "The update server could not be reached since %d days to check for new updates." : "Le serveur de mise à jour n'a pas pu être atteint depuis %d jours pour vérifier les nouvelles mises à jour.",
-    "Please check the Nextcloud and server log files for errors." : "Veuillez vérifier les fichiers de log de Nextcloud et du serveur pour les erreurs.",
-    "Update to %1$s is available." : "Une mise à jour vers %1$s est disponible",
-    "Update for %1$s to version %2$s is available." : "Une mise à jour de %1$s vers la version %2$s est disponible.",
-    "Update for {app} to version %s is available." : "Une mise à jour de {app} vers la version %s est disponible.",
-    "Update notification" : "Notification mise à jour",
     "A new version is available: %s" : "Une nouvelle version est disponible : %s",
     "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La version que vous utilisez n'est plus maintenue. Assurez vous d'effectuer une mise à jour vers une version prise en charge dès que possible.",
     "Download now" : "Télécharger maintenant",
+    "Your version is up to date." : "Votre version est à jour.",
     "Checked on %s" : "Vérifié le %s",
-    "The selected update channel makes dedicated notifications for the server obsolete." : "Le canal de mise à jour sélectionné rend obsolètes les notifications dédiées au serveur.",
-    "The update check is not yet finished. Please refresh the page." : "La vérification de la mise-à-jour n'est pas encore terminée. Veuillez rafraîchir la page."
+    "The selected update channel makes dedicated notifications for the server obsolete." : "Le canal de mise à jour sélectionné rend obsolètes les notifications dédiées au serveur."
 },
 "nplurals=2; plural=(n > 1);");
