@@ -27,18 +27,28 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
     "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
     "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerdia. ",
+    "Logged in user must be an admin" : "El usuario firmado debe ser un administrador",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
     "today" : "hoy",
+    "tomorrow" : "mañana",
     "yesterday" : "ayer",
+    "_in %n day_::_in %n days_" : ["en %n día","en %n días"],
     "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días"],
+    "next month" : "próximo mes",
     "last month" : "mes pasado",
+    "_in %n month_::_in %n months_" : ["en %n mes","en %n meses"],
     "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
+    "next year" : "próximo año",
     "last year" : "año pasado",
+    "_in %n year_::_in %n years_" : ["en %n año","en %n años"],
     "_%n year ago_::_%n years ago_" : ["hace %n año","hace %n años"],
+    "_in %n hour_::_in %n hours_" : ["en %n hora","en %n horas"],
     "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
+    "_in %n minute_::_in %n minutes_" : ["en %n minuto","en %n minutos"],
     "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
+    "in a few seconds" : "en algunos segundos",
     "seconds ago" : "hace segundos",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Por favor hablíitalo en tus configuraciones de aplicación o contacta a tu administrador.  ",
     "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
@@ -48,24 +58,26 @@ OC.L10N.register(
     "Empty filename is not allowed" : "El uso de nombres de archivo vacíos no está permitido",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "La aplicación \"%s\" no puede ser instalada porque el archivo appinfo no se puede leer. ",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplicación \"%s\" no puede ser instalada porque no es compatible con esta versión del servidor. ",
+    "__language_name__" : "Español (México)",
     "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, por favor no lo contestes. ",
     "Help" : "Ayuda",
     "Apps" : "Aplicaciones",
     "Settings" : "Configuraciones",
-    "Log out" : "Salir",
+    "Log out" : "Cerrar sesión",
     "Users" : "Usuarios",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
+    "Unknown user" : "Ususario desconocido",
+    "Create" : "Crear",
+    "Change" : "Cambiar",
+    "Delete" : "Borrar",
+    "Share" : "Compartir",
+    "Overview" : "Generalidades",
     "Basic settings" : "Configuraciones  básicas",
     "Sharing" : "Compartiendo",
     "Security" : "Seguridad",
-    "Encryption" : "Encripción",
     "Additional settings" : "Configuraciones adicionales",
-    "Tips & tricks" : "Consejos & trucos",
     "Personal info" : "Información personal",
-    "Sync clients" : "Sincronizar clientes",
+    "Mobile & desktop" : "Móvil & escritorio",
     "Unlimited" : "Ilimitado",
-    "__language_name__" : "Español (México)",
     "Verifying" : "Verficando",
     "Verifying …" : "Verficando ...",
     "Verify" : "Verificar",
@@ -110,6 +122,7 @@ OC.L10N.register(
     "Sharing %s failed, because resharing is not allowed" : "Falla al compartir %s debído a que no se permite volver a compartir",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Se presentó una falla al compartir  %s porque el backend que comparte %s no pudo encontrar su origen",
     "Sharing %s failed, because the file could not be found in the file cache" : "Se presentó una falla al compartir %s porque el archivo no se encontró en el caché de archivos",
+    "Open »%s«" : "Abrir »%s«",
     "Can’t increase permissions of %s" : "No es posible incrementar los privilegios de %s",
     "Files can’t be shared with delete permissions" : "Los archivos no se pueden compartir con permisos de borrado",
     "Files can’t be shared with create permissions" : "Los archivos no se pueden compartir con permisos de creación",
@@ -118,7 +131,6 @@ OC.L10N.register(
     "%s shared »%s« with you" : "%s ha compartido  »%s« contigo",
     "%s shared »%s« with you." : "%s compartió contigo »%s«.",
     "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
-    "Open »%s«" : "Abrir »%s«",
     "%s via %s" : "%s por %s",
     "The requested share does not exist anymore" : "El recurso compartido solicitado ya no existe",
     "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
@@ -176,8 +188,6 @@ OC.L10N.register(
     "Could not create user" : "No fue posible crear el usuario",
     "User disabled" : "Usuario deshabilitado",
     "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
-    "No app name specified" : "No se ha especificado el nombre de la aplicación",
-    "App '%s' could not be installed!" : "¡La aplicación \"%s\" no pudo ser instalada!",
     "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "La aplicación \"%s\" no puede ser instalada porque las siguientes dependencias no están satisfechas: %s ",
     "a safe home for all your data" : "un lugar seguro para todos tus datos",
     "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, por favor intentalo más tarde. ",
@@ -185,7 +195,6 @@ OC.L10N.register(
     "Application is not enabled" : "La aplicación está deshabilitada",
     "Authentication error" : "Error de autenticación",
     "Token expired. Please reload page." : "La ficha ha expirado. Por favor recarga la página.",
-    "Unknown user" : "Ususario desconocido",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "No cuentas con controladores de base de datos (sqlite, mysql o postgresql) instalados. ",
     "Cannot write into \"config\" directory" : "No fue posible escribir en el directorio \"config\"",
     "Cannot write into \"apps\" directory" : "No fue posible escribir en el directorio \"apps\"",
@@ -221,29 +230,24 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
-    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Esto generalmente se soluciona %s dándole al servidor web acceso para escribir en el directorio config %s.",
-    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con id: %s no existe. Por favor habilítalo en tus configuraciones de aplicación o contacta a tu administrador. ",
-    "Server settings" : "Configuraciones del servidor",
-    "DB Error: \"%s\"" : "Error de BD: \"%s\"",
-    "Offending command was: \"%s\"" : "El comando infractor fue: \"%s\"",
-    "You need to enter either an existing account or the administrator." : "Necesitas ingresar una cuenta ya existente o la del administrador.",
-    "Offending command was: \"%s\", name: %s, password: %s" : "El comando infractor fue: \"%s\", nombre: %s, contraseña: %s",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Se presentó una falla al establecer los permisos para %s, porque los permisos exceden los permisos otorgados a %s",
-    "Setting permissions for %s failed, because the item was not found" : "Se persentó una falla al establecer los permisos para %s, porque no se encontró el elemento ",
-    "Cannot clear expiration date. Shares are required to have an expiration date." : "No ha sido posible borrar la fecha de expiración. Los elelentos compartidos deben tener una fecha de expiración.",
-    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
-    "Files can't be shared with delete permissions" : "No es posible compartir archivos con permisos de borrado",
-    "Files can't be shared with create permissions" : "No es posible compartir archivos con permisos de creación",
-    "Cannot set expiration date more than %s days in the future" : "No es posible establecer la fecha de expiración más allá de %s días en el futuro",
     "Personal" : "Personal",
-    "Admin" : "Administración",
-    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Esto se puede arreglar por %s al darle acceso de escritura al servidor web al directorio de las aplicaciones %s o al deshabilitar la tienda de aplicaciones en el archivo de configuración",
-    "Cannot create \"data\" directory (%s)" : "No fue posible crear el directorio de \"datos\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Esto se puede arreglar generalmente al <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">darle al servidor web accesos al directorio raíz</a>.",
-    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Los permisos se pueden arreglar generalmente al %s darle al servidor web accesos al direcotiro raíz %s.",
-    "Data directory (%s) is readable by other users" : "El directorio de datos (%s) puede ser leído por otros usuarios",
-    "Data directory (%s) must be an absolute path" : "El directorio de datos (%s) debe ser una ruta absoluta",
-    "Data directory (%s) is invalid" : "El directorio de datos (%s) es inválido",
-    "Please check that the data directory contains a file \".ocdata\" in its root." : "Por favor verifica que el directorio de datos tenga un archivo \".ocdata\" en su raíz. "
+    "Admin" : "Admin",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Encryption" : "Encripción",
+    "Tips & tricks" : "Consejos & trucos",
+    "DB Error: \"%s\"" : "DB Error: \"%s\"",
+    "Offending command was: \"%s\"" : "El comando infractor fue: \"%s\"",
+    "Offending command was: \"%s\", name: %s, password: %s" : "El comando infractor fue: \"%s\", nombre:%s, contraseña:%s",
+    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Se presentó una falla al establecer los permisos de %s, porque los permisos excenden los permisos otorgados a  %s",
+    "Setting permissions for %s failed, because the item was not found" : "Se presentó una falla al establecer los permisos de %s, porque no se encontró el elemento",
+    "Cannot clear expiration date. Shares are required to have an expiration date." : "No se puede limpíar la fecha de expiración. Se requiere que los elementos compartidos tengan una fecha de expiración.",
+    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
+    "Files can't be shared with delete permissions" : "No se pueden compartir archivos con privilegios para borrar",
+    "Files can't be shared with create permissions" : "No se pueden compartir archivos con privilegios para crear",
+    "Cannot set expiration date more than %s days in the future" : "No se puede establecer la fecha de expiración más alla de %s días en el futuro",
+    "No app name specified" : "No se especificó el nombre de la aplicación",
+    "App '%s' could not be installed!" : "¡No se pudo instalar la aplciación '%s'!",
+    "Sync clients" : "Sincronizar clientes"
 },
 "nplurals=2; plural=(n != 1);");
