@@ -7,6 +7,7 @@
  * @author Bernhard Posselt <dev@bernhard-posselt.com>
  * @author Joas Schilling <coding@schilljs.com>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
+ * @author Knut Ahlers <knut@ahlers.me>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author macjohnny <estebanmarin@gmx.ch>
  * @author Morris Jobke <hey@morrisjobke.de>
@@ -15,7 +16,9 @@
  * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Roman Kreisel <mail@romankreisel.de>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author voxsim <Simon Vocella>
+ * @author Vincent Petry <pvince81@owncloud.com>
+ * @author Vinicius Cubas Brand <vinicius@eita.org.br>
+ * @author voxsim "Simon Vocella"
  *
  * @license AGPL-3.0
  *
@@ -74,7 +77,7 @@ class Manager extends PublicEmitter implements IGroupManager {
 	private $cachedGroups = array();
 
 	/**
-	 * @var \OC\Group\Group[][]
+	 * @var \OC\Group\Group[]
 	 */
 	private $cachedUserGroups = array();
 
@@ -144,7 +147,16 @@ class Manager extends PublicEmitter implements IGroupManager {
 		$this->backends = array();
 		$this->clearCaches();
 	}
-	
+
+	/**
+	 * Get the active backends
+	 * @return \OCP\GroupInterface[]
+	 */
+	public function getBackends() {
+		return $this->backends;
+	}
+
+
 	protected function clearCaches() {
 		$this->cachedGroups = array();
 		$this->cachedUserGroups = array();
@@ -163,19 +175,29 @@ class Manager extends PublicEmitter implements IGroupManager {
 
 	/**
 	 * @param string $gid
+	 * @param string $displayName
 	 * @return \OCP\IGroup
 	 */
-	protected function getGroupObject($gid) {
+	protected function getGroupObject($gid, $displayName = null) {
 		$backends = array();
 		foreach ($this->backends as $backend) {
-			if ($backend->groupExists($gid)) {
+			if ($backend->implementsActions(\OC\Group\Backend::GROUP_DETAILS)) {
+				$groupData = $backend->getGroupDetails($gid);
+				if (is_array($groupData)) {
+					// take the display name from the first backend that has a non-null one
+					if (is_null($displayName) && isset($groupData['displayName'])) {
+						$displayName = $groupData['displayName'];
+					}
+					$backends[] = $backend;
+				}
+			} else if ($backend->groupExists($gid)) {
 				$backends[] = $backend;
 			}
 		}
 		if (count($backends) === 0) {
 			return null;
 		}
-		$this->cachedGroups[$gid] = new Group($gid, $backends, $this->userManager, $this);
+		$this->cachedGroups[$gid] = new Group($gid, $backends, $this->userManager, $this, $displayName);
 		return $this->cachedGroups[$gid];
 	}
 
@@ -236,10 +258,10 @@ class Manager extends PublicEmitter implements IGroupManager {
 	}
 
 	/**
-	 * @param \OC\User\User|null $user
+	 * @param IUser|null $user
 	 * @return \OC\Group\Group[]
 	 */
-	public function getUserGroups($user) {
+	public function getUserGroups(IUser $user= null) {
 		if (!$user instanceof IUser) {
 			return [];
 		}
@@ -278,6 +300,11 @@ class Manager extends PublicEmitter implements IGroupManager {
 	 * @return bool if admin
 	 */
 	public function isAdmin($userId) {
+		foreach ($this->backends as $backend) {
+			if ($backend->implementsActions(\OC\Group\Backend::IS_ADMIN) && $backend->isAdmin($userId)) {
+				return true;
+			}
+		}
 		return $this->isInGroup($userId, 'admin');
 	}
 
@@ -293,10 +320,10 @@ class Manager extends PublicEmitter implements IGroupManager {
 
 	/**
 	 * get a list of group ids for a user
-	 * @param \OC\User\User $user
+	 * @param IUser $user
 	 * @return array with group ids
 	 */
-	public function getUserGroupIds($user) {
+	public function getUserGroupIds(IUser $user) {
 		return array_map(function($value) {
 			return (string) $value;
 		}, array_keys($this->getUserGroups($user)));
