@@ -12,10 +12,11 @@
  * @author Christopher Schäpers <kondou@ts.unde.re>
  * @author Felix Moeller <mail@felixmoeller.de>
  * @author Frank Karlitschek <frank@karlitschek.de>
- * @author Georg Ehrke <georg@owncloud.com>
+ * @author Georg Ehrke <oc.list@georgehrke.com>
  * @author Jakob Sack <mail@jakobsack.de>
- * @author Jan-Christoph Borchardt <hey@jancborchardt.net>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author Julius Haertl <jus@bitgrid.net>
+ * @author Julius Härtl <jus@bitgrid.net>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
  * @author Kamil Domanski <kdomanski@kdemail.net>
  * @author Klaas Freitag <freitag@owncloud.com>
@@ -27,6 +28,7 @@
  * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Sam Tuke <mail@samtuke.com>
+ * @author Sebastian Wessalowski <sebastian@wessalowski.org>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Thomas Tanghus <thomas@tanghus.net>
  * @author Tom Needham <tom@owncloud.com>
@@ -50,6 +52,7 @@
 use OC\App\DependencyAnalyzer;
 use OC\App\InfoParser;
 use OC\App\Platform;
+use OC\DB\MigrationService;
 use OC\Installer;
 use OC\Repair;
 use OCP\App\ManagerEvent;
@@ -182,6 +185,22 @@ class OC_App {
 				\OC::$server->getActivityManager()->registerProvider($provider);
 			}
 		}
+		if (!empty($info['collaboration']['plugins'])) {
+			// deal with one or many plugin entries
+			$plugins = isset($info['collaboration']['plugins']['plugin']['@value']) ?
+				[$info['collaboration']['plugins']['plugin']] : $info['collaboration']['plugins']['plugin'];
+			foreach ($plugins as $plugin) {
+				if($plugin['@attributes']['type'] === 'collaborator-search') {
+					$pluginInfo = [
+						'shareType' => $plugin['@attributes']['share-type'],
+						'class' => $plugin['@value'],
+					];
+					\OC::$server->getCollaboratorSearch()->registerPlugin($pluginInfo);
+				} else if ($plugin['@attributes']['type'] === 'autocomplete-sort') {
+					\OC::$server->getAutoCompleteManager()->registerSorter($plugin['@value']);
+				}
+			}
+		}
 	}
 
 	/**
@@ -194,17 +213,25 @@ class OC_App {
 		if(isset(self::$alreadyRegistered[$key])) {
 			return;
 		}
+
 		self::$alreadyRegistered[$key] = true;
+
 		// Register on PSR-4 composer autoloader
 		$appNamespace = \OC\AppFramework\App::buildAppNamespace($app);
 		\OC::$server->registerNamespace($app, $appNamespace);
-		\OC::$composerAutoloader->addPsr4($appNamespace . '\\', $path . '/lib/', true);
+
+		if (file_exists($path . '/composer/autoload.php')) {
+			require_once $path . '/composer/autoload.php';
+		} else {
+			\OC::$composerAutoloader->addPsr4($appNamespace . '\\', $path . '/lib/', true);
+			// Register on legacy autoloader
+			\OC::$loader->addValidRoot($path);
+		}
+
+		// Register Test namespace only when testing
 		if (defined('PHPUNIT_RUN') || defined('CLI_TEST_RUN')) {
 			\OC::$composerAutoloader->addPsr4($appNamespace . '\\Tests\\', $path . '/tests/', true);
 		}
-
-		// Register on legacy autoloader
-		\OC::$loader->addValidRoot($path);
 	}
 
 	/**
@@ -283,18 +310,6 @@ class OC_App {
 		}
 	}
 
-	/**
-	 * check if app is shipped
-	 *
-	 * @param string $appId the id of the app to check
-	 * @return bool
-	 *
-	 * Check if an app that is installed is a shipped app or installed from the appstore.
-	 */
-	public static function isShipped($appId) {
-		return \OC::$server->getAppManager()->isShipped($appId);
-	}
-
 	/**
 	 * get all enabled apps
 	 */
@@ -339,6 +354,7 @@ class OC_App {
 	 *
 	 * @param string $app app
 	 * @return bool
+	 * @deprecated 13.0.0 use \OC::$server->getAppManager()->isEnabledForUser($appId)
 	 *
 	 * This function checks whether or not an app is enabled.
 	 */
@@ -361,13 +377,7 @@ class OC_App {
 		self::$enabledAppsCache = []; // flush
 
 		// Check if app is already downloaded
-		$installer = new Installer(
-			\OC::$server->getAppFetcher(),
-			\OC::$server->getHTTPClientService(),
-			\OC::$server->getTempManager(),
-			\OC::$server->getLogger(),
-			\OC::$server->getConfig()
-		);
+		$installer = \OC::$server->query(Installer::class);
 		$isDownloaded = $installer->isDownloaded($appId);
 
 		if(!$isDownloaded) {
@@ -397,17 +407,11 @@ class OC_App {
 	 * @return bool
 	 */
 	public static function removeApp($app) {
-		if (self::isShipped($app)) {
+		if (\OC::$server->getAppManager()->isShipped($app)) {
 			return false;
 		}
 
-		$installer = new Installer(
-			\OC::$server->getAppFetcher(),
-			\OC::$server->getHTTPClientService(),
-			\OC::$server->getTempManager(),
-			\OC::$server->getLogger(),
-			\OC::$server->getConfig()
-		);
+		$installer = \OC::$server->query(Installer::class);
 		return $installer->removeApp($app);
 	}
 
@@ -514,7 +518,7 @@ class OC_App {
 		} else {
 			$versionToLoad = array();
 			foreach ($possibleApps as $possibleApp) {
-				$version = self::getAppVersionByPath($possibleApp['path']);
+				$version = self::getAppVersionByPath($possibleApp['path'] . '/' . $appId);
 				if (empty($versionToLoad) || version_compare($version, $versionToLoad['version'], '>')) {
 					$versionToLoad = array(
 						'dir' => $possibleApp,
@@ -613,7 +617,7 @@ class OC_App {
 			$file = $appPath . '/appinfo/info.xml';
 		}
 
-		$parser = new InfoParser(\OC::$server->getMemCacheFactory()->create('core.appinfo'));
+		$parser = new InfoParser(\OC::$server->getMemCacheFactory()->createLocal('core.appinfo'));
 		$data = $parser->parse($file);
 
 		if (is_array($data)) {
@@ -767,6 +771,8 @@ class OC_App {
 			}
 		}
 
+		$apps = array_unique($apps);
+
 		return $apps;
 	}
 
@@ -778,8 +784,9 @@ class OC_App {
 	public function listAllApps() {
 		$installedApps = OC_App::getAllApps();
 
+		$appManager = \OC::$server->getAppManager();
 		//we don't want to show configuration for these
-		$blacklist = \OC::$server->getAppManager()->getAlwaysEnabledApps();
+		$blacklist = $appManager->getAlwaysEnabledApps();
 		$appList = array();
 		$langCode = \OC::$server->getL10N('core')->getLanguageCode();
 		$urlGenerator = \OC::$server->getURLGenerator();
@@ -811,7 +818,7 @@ class OC_App {
 
 				$info['active'] = $active;
 
-				if (self::isShipped($app)) {
+				if ($appManager->isShipped($app)) {
 					$info['internal'] = true;
 					$info['level'] = self::officialApp;
 					$info['removable'] = false;
@@ -824,12 +831,12 @@ class OC_App {
 				if($appPath !== false) {
 					$appIcon = $appPath . '/img/' . $app . '.svg';
 					if (file_exists($appIcon)) {
-						$info['preview'] = \OC::$server->getURLGenerator()->imagePath($app, $app . '.svg');
+						$info['preview'] = $urlGenerator->imagePath($app, $app . '.svg');
 						$info['previewAsIcon'] = true;
 					} else {
 						$appIcon = $appPath . '/img/app.svg';
 						if (file_exists($appIcon)) {
-							$info['preview'] = \OC::$server->getURLGenerator()->imagePath($app, 'app.svg');
+							$info['preview'] = $urlGenerator->imagePath($app, 'app.svg');
 							$info['previewAsIcon'] = true;
 						}
 					}
@@ -855,21 +862,6 @@ class OC_App {
 		return $appList;
 	}
 
-	/**
-	 * Returns the internal app ID or false
-	 * @param string $ocsID
-	 * @return string|false
-	 */
-	public static function getInternalAppIdByOcs($ocsID) {
-		if(is_numeric($ocsID)) {
-			$idArray = \OC::$server->getAppConfig()->getValues(false, 'ocsid');
-			if(array_search($ocsID, $idArray)) {
-				return array_search($ocsID, $idArray);
-			}
-		}
-		return false;
-	}
-
 	public static function shouldUpgrade($app) {
 		$versions = self::getAppVersions();
 		$currentVersion = OC_App::getAppVersion($app);
@@ -1043,20 +1035,27 @@ class OC_App {
 		if($appPath === false) {
 			return false;
 		}
+		self::registerAutoloading($appId, $appPath);
+
 		$appData = self::getAppInfo($appId);
 		self::executeRepairSteps($appId, $appData['repair-steps']['pre-migration']);
+
 		if (file_exists($appPath . '/appinfo/database.xml')) {
 			OC_DB::updateDbFromStructure($appPath . '/appinfo/database.xml');
+		} else {
+			$ms = new MigrationService($appId, \OC::$server->getDatabaseConnection());
+			$ms->migrate();
 		}
+
 		self::executeRepairSteps($appId, $appData['repair-steps']['post-migration']);
 		self::setupLiveMigrations($appId, $appData['repair-steps']['live-migration']);
 		unset(self::$appVersion[$appId]);
+
 		// run upgrade code
 		if (file_exists($appPath . '/appinfo/update.php')) {
 			self::loadApp($appId);
 			include $appPath . '/appinfo/update.php';
 		}
-		self::registerAutoloading($appId, $appPath);
 		self::setupBackgroundJobs($appData['background-jobs']);
 		if(isset($appData['settings']) && is_array($appData['settings'])) {
 			\OC::$server->getSettingsManager()->setupSettings($appData['settings']);
@@ -1140,7 +1139,7 @@ class OC_App {
 	 * @return \OC\Files\View|false
 	 */
 	public static function getStorage($appId) {
-		if (OC_App::isEnabled($appId)) { //sanity check
+		if (\OC::$server->getAppManager()->isEnabledForUser($appId)) { //sanity check
 			if (\OC::$server->getUserSession()->isLoggedIn()) {
 				$view = new \OC\Files\View('/' . OC_User::getUser());
 				if (!$view->file_exists($appId)) {
@@ -1158,6 +1157,11 @@ class OC_App {
 	}
 
 	protected static function findBestL10NOption($options, $lang) {
+		// only a single option
+		if (isset($options['@value'])) {
+			return $options['@value'];
+		}
+
 		$fallback = $similarLangFallback = $englishFallback = false;
 
 		$lang = strtolower($lang);
@@ -1238,7 +1242,7 @@ class OC_App {
 		$dependencyAnalyzer = new DependencyAnalyzer(new Platform($config), $l);
 		$missing = $dependencyAnalyzer->analyze($info);
 		if (!empty($missing)) {
-			$missingMsg = join(PHP_EOL, $missing);
+			$missingMsg = implode(PHP_EOL, $missing);
 			throw new \Exception(
 				$l->t('App "%s" cannot be installed because the following dependencies are not fulfilled: %s',
 					[$info['name'], $missingMsg]
